cosinnus package
================

Subpackages
-----------

.. toctree::

    cosinnus.core
    cosinnus.formats
    cosinnus.forms
    cosinnus.models
    cosinnus.templatetags
    cosinnus.utils
    cosinnus.views

Submodules
----------

cosinnus.admin module
---------------------

.. automodule:: cosinnus.admin
    :members:
    :undoc-members:
    :show-inheritance:

cosinnus.conf module
--------------------

.. automodule:: cosinnus.conf
    :members:
    :undoc-members:
    :show-inheritance:

cosinnus.urls module
--------------------

.. automodule:: cosinnus.urls
    :members:
    :undoc-members:
    :show-inheritance:

cosinnus.urls_api module
------------------------

.. automodule:: cosinnus.urls_api
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cosinnus
    :members:
    :undoc-members:
    :show-inheritance:
